@@ -60,7 +60,7 @@ class CfnAssessmentTarget(
             resource_group_arn=resource_group_arn,
         )
 
-        jsii.create(CfnAssessmentTarget, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -225,7 +225,7 @@ class CfnAssessmentTemplate(
             user_attributes_for_findings=user_attributes_for_findings,
         )
 
-        jsii.create(CfnAssessmentTemplate, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -465,7 +465,7 @@ class CfnResourceGroup(
         '''
         props = CfnResourceGroupProps(resource_group_tags=resource_group_tags)
 
-        jsii.create(CfnResourceGroup, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
